@@ -1,5 +1,6 @@
 from outcome.logkit import context
+from outcome.logkit.features import feature_set
 from outcome.logkit.init import init as init_logging
 from outcome.logkit.logger import get_logger
 
-__all__ = ['init_logging', 'get_logger', 'context']
+__all__ = ['init_logging', 'get_logger', 'context', 'feature_set']
