@@ -1,29 +1,30 @@
 """Outputs Stackdriver-compliant JSON."""
 
 from datetime import datetime
-from typing import cast
+from typing import Union, cast
 
 import structlog
 from outcome.logkit.types import EventDict
 
 
 class StackdriverRenderer(structlog.processors.JSONRenderer):
-    def __call__(self, logger: object, name: str, event_dict: EventDict):
+    def __call__(self, logger: object, name: str, event_dict: EventDict) -> Union[str, bytes]:
         return super().__call__(logger, name, self.format_for_stackdriver(event_dict))
 
     @classmethod
     def format_for_stackdriver(cls, event_dict: EventDict):
-        level = event_dict.pop('level', None)
+        formatted_dict = dict(event_dict)
+        level = formatted_dict.pop('level', None)
         if level:
-            event_dict['severity'] = level
+            formatted_dict['severity'] = level
 
-        event = event_dict.pop('event', None)
+        event = formatted_dict.pop('event', None)
         if event:
-            event_dict['message'] = event
+            formatted_dict['message'] = event
         else:
-            event_dict['message'] = ''
+            formatted_dict['message'] = ''
 
-        timestamp = event_dict.pop('timestamp', None)
+        timestamp = formatted_dict.pop('timestamp', None)
         if timestamp:
             try:
                 ts = datetime.fromtimestamp(cast(float, timestamp)).isoformat('T')
@@ -34,6 +35,6 @@ class StackdriverRenderer(structlog.processors.JSONRenderer):
             ts = datetime.now().isoformat('T')
             timestamp_str = f'{ts}Z'
 
-        event_dict['timestamp'] = timestamp_str
+        formatted_dict['timestamp'] = timestamp_str
 
-        return event_dict
+        return formatted_dict
